@@ -1,6 +1,7 @@
 /****************************************************************************
 **
 ** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2019 Jochen Ulrich <jochenulrich@t-online.de>
 ** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of Qbs.
@@ -39,6 +40,8 @@ public:
     TestBlackbox();
 
 private slots:
+    void allowedValues();
+    void allowedValues_data();
     void addFileTagToGeneratedArtifact();
     void alwaysRun();
     void alwaysRun_data();
@@ -48,6 +51,8 @@ private slots:
     void artifactScanning();
     void assembly();
     void autotestWithDependencies();
+    void autotestTimeout();
+    void autotestTimeout_data();
     void autotests_data();
     void autotests();
     void auxiliaryInputsFromDependencies();
@@ -57,6 +62,10 @@ private slots:
     void buildDirectories();
     void buildEnvChange();
     void buildGraphVersions();
+    void buildVariantDefaults_data();
+    void buildVariantDefaults();
+    void capnproto();
+    void capnproto_data();
     void changedFiles_data();
     void changedFiles();
     void changedInputsFromDependencies();
@@ -73,26 +82,30 @@ private slots:
     void combinedSources();
     void commandFile();
     void compilerDefinesByLanguage();
-    void concurrentExecutor();
     void conditionalExport();
     void conditionalFileTagger();
     void configure();
     void conflictingArtifacts();
     void cxxLanguageVersion();
     void cxxLanguageVersion_data();
+    void conanfileProbe_data();
+    void conanfileProbe();
     void cpuFeatures();
     void dependenciesProperty();
-    void dependencyProfileMismatch();
+    void dependencyScanningLoop();
     void deprecatedProperty();
+    void deprecatedProperty_data();
     void disappearedProfile();
     void discardUnusedData();
     void discardUnusedData_data();
+    void dotDotPcFile();
     void driverLinkerFlags();
     void driverLinkerFlags_data();
     void dynamicLibraryInModule();
     void dynamicMultiplexRule();
     void dynamicProject();
     void dynamicRuleOutputs();
+    void emptyProfile();
     void enableExceptions();
     void enableExceptions_data();
     void enableRtti();
@@ -115,10 +128,15 @@ private slots:
     void externalLibs();
     void fileDependencies();
     void fileTagsFilterMerging();
+    void freedesktop();
     void generatedArtifactAsInputToDynamicRule();
+    void generateLinkerMapFile();
     void generator();
     void generator_data();
     void groupsInModules();
+    void grpc_data();
+    void grpc();
+    void hostOsProperties();
     void ico();
     void importAssignment();
     void importChangeTracking();
@@ -127,8 +145,6 @@ private slots:
     void importingProduct();
     void importsConflict();
     void includeLookup();
-    void innoSetup();
-    void innoSetupDependencies();
     void inputTagsChangeTracking_data();
     void inputTagsChangeTracking();
     void inputsFromDependencies();
@@ -153,11 +169,13 @@ private slots:
     void invalidLibraryNames_data();
     void jsExtensionsFile();
     void jsExtensionsFileInfo();
+    void jsExtensionsHost();
     void jsExtensionsProcess();
     void jsExtensionsPropertyList();
     void jsExtensionsTemporaryDir();
     void jsExtensionsTextFile();
     void jsExtensionsBinaryFile();
+    void lastModuleCandidateBroken();
     void ld();
     void linkerMode();
     void linkerVariant_data();
@@ -165,7 +183,10 @@ private slots:
     void lexyacc();
     void lexyaccOutputs();
     void lexyaccOutputs_data();
+    void linkerLibraryDuplicates();
+    void linkerLibraryDuplicates_data();
     void linkerScripts();
+    void linkerModuleDefinition();
     void listProducts();
     void listPropertiesWithOuter();
     void listPropertyOrder();
@@ -204,7 +225,10 @@ private slots:
     void nsisDependencies();
     void outOfDateMarking();
     void outputArtifactAutoTagging();
+    void outputRedirection();
     void overrideProjectProperties();
+    void pathProbe_data();
+    void pathProbe();
     void pchChangeTracking();
     void perGroupDefineInExportItem();
     void pkgConfigProbe();
@@ -212,25 +236,42 @@ private slots:
     void pkgConfigProbeSysroot();
     void pluginDependency();
     void precompiledAndPrefixHeaders();
+    void precompiledHeaderAndRedefine();
     void preventFloatingPointValues();
     void probeChangeTracking();
     void probeProperties();
     void probesAndShadowProducts();
     void probeInExportedModule();
+    void probeInModuleProvider();
     void probesAndArrayProperties();
     void probesInNestedModules();
     void productDependenciesByType();
+    void productInExportedModule();
     void productProperties();
     void propertyAssignmentOnNonPresentModule();
     void propertyAssignmentInFailedModule();
     void propertyChanges();
+    void propertyEvaluationContext();
     void propertyPrecedence();
     void properQuoting();
     void propertiesInExportItems();
     void protobuf_data();
     void protobuf();
+    void protobufLibraryInstall();
+    void providersProperties();
     void pseudoMultiplexing();
     void qbsConfig();
+    void qbsConfigAddProfile();
+    void qbsConfigAddProfile_data();
+    void qbsModulePropertiesInProviders();
+    void qbsModuleProviders();
+    void qbsModuleProviders_data();
+    void qbsModuleProvidersCliOverride();
+    void qbsModuleProvidersCliOverride_data();
+    void qbsModuleProvidersCompatibility();
+    void qbsModuleProvidersCompatibility_data();
+    void qbspkgconfigModuleProvider();
+    void qbsSession();
     void qbsVersion();
     void qtBug51237();
     void radAfterIncompleteBuild();
@@ -238,10 +279,11 @@ private slots:
     void recursiveRenaming();
     void recursiveWildcards();
     void referenceErrorInExport();
+    void removeDuplicateLibraries_data();
+    void removeDuplicateLibraries();
     void reproducibleBuild();
     void reproducibleBuild_data();
     void require();
-    void requireDeprecated();
     void rescueTransformerData();
     void responseFiles();
     void retaggedOutputArtifact();
@@ -250,7 +292,11 @@ private slots:
     void ruleCycle();
     void ruleWithNoInputs();
     void ruleWithNonRequiredInputs();
+    void sanitizer_data();
+    void sanitizer();
     void scannerItem();
+    void scanResultInOtherProduct();
+    void scanResultInNonDependency();
     void setupBuildEnvironment();
     void setupRunEnvironment();
     void smartRelinking();
@@ -270,6 +316,7 @@ private slots:
     void suspiciousCalls();
     void suspiciousCalls_data();
     void systemIncludePaths();
+    void distributionIncludePaths();
     void systemRunPaths();
     void systemRunPaths_data();
     void tar();
@@ -284,8 +331,10 @@ private slots:
     void trackRemoveFile();
     void trackRemoveFileTag();
     void trackRemoveProduct();
+    void transitiveInvalidDependencies();
     void transitiveOptionalDependencies();
     void typescript();
+    void undefinedTargetPlatform();
     void usingsAsSoleInputsNonMultiplexed();
     void variantSuffix();
     void variantSuffix_data();
@@ -298,8 +347,6 @@ private slots:
     void wholeArchive_data();
     void wildCardsAndRules();
     void wildcardRenaming();
-    void wix();
-    void wixDependencies();
     void zip();
     void zip_data();
     void zipInvalid();
@@ -310,6 +357,7 @@ private:
     QMap<QString, QString> findTypeScript(int *status);
     QString findArchiver(const QString &fileName, int *status = nullptr);
     static bool lexYaccExist();
+    static qbs::Version bisonVersion();
 };
 
 #endif // TST_BLACKBOX_H
